Crate kcr_operator_shipwright_io

Crate kcr_operator_shipwright_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the operator.shipwright.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

operator.shipwright.io/v1alpha1

  • ShipwrightBuild

Modules

v1alpha1